pub struct Layer {
pub version: u32,
pub name: String,
pub features: Vec<Feature>,
pub keys: Vec<String>,
pub values: Vec<Value>,
pub extent: Option<u32>,
}Expand description
Layers are described in section 4.1 of the specification
Fields
version: u32Any compliant implementation must first read the version number encoded in this message and choose the correct implementation for this version number before proceeding to decode other parts of this message.
Field 15: version
name: StringField 1: name
features: Vec<Feature>The actual features in this tile.
Field 2: features
keys: Vec<String>Dictionary encoding for keys
Field 3: keys
values: Vec<Value>Dictionary encoding for values
Field 4: values
extent: Option<u32>Although this is an “optional” field it is required by the specification. See https://github.com/mapbox/vector-tile-spec/issues/47
Field 5: extent
Implementations
Sourceimpl Layer
impl Layer
Sourcepub fn with_extent(self, value: u32) -> Self
pub fn with_extent(self, value: u32) -> Self
Sets Self::extent to Some(value), consuming and returning self.