pub struct Value {
pub string_value: Option<String>,
pub float_value: Option<f32>,
pub double_value: Option<f64>,
pub int_value: Option<i64>,
pub uint_value: Option<u64>,
pub sint_value: Option<i64>,
pub bool_value: Option<bool>,
}Expand description
Variant type encoding The use of values is described in section 4.1 of the specification
Fields
string_value: Option<String>Exactly one of these values must be present in a valid message
Field 1: string_value
float_value: Option<f32>Field 2: float_value
double_value: Option<f64>Field 3: double_value
int_value: Option<i64>Field 4: int_value
uint_value: Option<u64>Field 5: uint_value
sint_value: Option<i64>Field 6: sint_value
bool_value: Option<bool>Field 7: bool_value
Implementations
Sourceimpl Value
impl Value
Sourcepub fn with_string_value(self, value: impl Into<String>) -> Self
pub fn with_string_value(self, value: impl Into<String>) -> Self
Sets Self::string_value to Some(value), consuming and returning self.
Sourcepub fn with_float_value(self, value: f32) -> Self
pub fn with_float_value(self, value: f32) -> Self
Sets Self::float_value to Some(value), consuming and returning self.
Sourcepub fn with_double_value(self, value: f64) -> Self
pub fn with_double_value(self, value: f64) -> Self
Sets Self::double_value to Some(value), consuming and returning self.
Sourcepub fn with_int_value(self, value: i64) -> Self
pub fn with_int_value(self, value: i64) -> Self
Sets Self::int_value to Some(value), consuming and returning self.
Sourcepub fn with_uint_value(self, value: u64) -> Self
pub fn with_uint_value(self, value: u64) -> Self
Sets Self::uint_value to Some(value), consuming and returning self.
Sourcepub fn with_sint_value(self, value: i64) -> Self
pub fn with_sint_value(self, value: i64) -> Self
Sets Self::sint_value to Some(value), consuming and returning self.
Sourcepub fn with_bool_value(self, value: bool) -> Self
pub fn with_bool_value(self, value: bool) -> Self
Sets Self::bool_value to Some(value), consuming and returning self.